@@ -551,13 +551,24 @@ def o_update_collision_lists(self):
         room = sge.game.current_room
         for area in self.rd["collision_areas"]:
             if area not in my_areas:
-                if area is not None:
-                    i, j = area
+                if area is None:
+                    area = (None, None)
+                i, j = area
+                if (i in room.rd["collision_areas"] and
+                        j in room.rd["collision_areas"][i]):
                     ca = room.rd["collision_areas"][i][j][:]
                     while self in ca:
                         ca.remove(self)
                     room.rd["collision_areas"][i][j] = ca
                 else:
+                    if i is not None or j is not None:
+                        e = "A collision area existed in a {} object, but not in the room!".format(
+                            self.__class__.__name__)
+                        warnings.warn(e)
+                        print("Attempted area: ({}, {})".format(i, j))
+                        print("Available collision areas:")
+                        print(room.rd["collision_areas"])
+
                     ca = room.rd["collision_area_void"][:]
                     while self in ca:
                         ca.remove(self)
@@ -565,12 +576,23 @@ def o_update_collision_lists(self):
 
         for area in my_areas:
             if area not in self.rd["collision_areas"]:
-                if area is not None:
-                    i, j = area
+                if area is None:
+                    area = (None, None)
+                i, j = area
+                if (i in room.rd["collision_areas"] and
+                        j in room.rd["collision_areas"][i]):
                     ca = room.rd["collision_areas"][i][j][:]
                     ca.append(self)
                     room.rd["collision_areas"][i][j] = ca
                 else:
+                    if i is not None or j is not None:
+                        e = "A collision area existed in a {} object, but not in the room!".format(
+                            self.__class__.__name__)
+                        warnings.warn(e)
+                        print("Attempted area: ({}, {})".format(i, j))
+                        print("Available collision areas:")
+                        print(room.rd["collision_areas"])
+
                     ca = room.rd["collision_area_void"][:]
                     ca.append(self)
                     room.rd["collision_area_void"] = ca
